@@ -19,7 +19,7 @@
 #Date last Update : 12/03/2020
 
 ##import the plugin handler
-from vmodules.base import plugin1 as plugin1
+#from vmodules.base import plugin1 as plugin1
 
 
 
