@@ -30,7 +30,7 @@ help_=[("Vampiria python main:","dirmain(directory path main),id(id process),deb
 
 if __name__ == "__main__":
   args=sys.argv_get()
-  if (len(args) is 4):  
+  if (len(args) == 4):  
      input_=sys.isdict(args[3])
      if input_ is not None:
        if args[2] == "True":  
