@@ -101,9 +101,9 @@ void vmp_init_time(pylib::Module module);
 //!Python wrapper of the c++ namespaces vampiria::vmp::unicode in vmp.unicode.(see c++ doc)
 /*!
     Function c++ in vmp/unicode.h:<BR>str_split(),str_join(),str_isdigit(),str_isxdigit(),str_isreal(),
-    str_todigit(),str_todigit_range(),str_toreal(),str_toreal_range(),xstr_tobytes(),bytes_toxstr(),
-    str_findsub(),str_isword(),str_format(),str_format_maxline(),str_format_end(),
-    str_extract_char(),str_regex_posix_icase(),str_toxstr(),xstr_tostr(),bytes_toxstr_hm()
+    str_todigit(),str_todigit_range(),str_toreal(),str_toreal_range(),xstr_tobytes(),bytes_toxstr(),bytes_toxstr_hm()
+    str_toxstr(),xstr_tostr(),str_sub(),str_findsub(),str_replace(),str_isword(),str_format(),str_format_maxline(),str_format_end(),
+    str_extract_char(),str_remove_duplex(),str_regex
 */
 void vmp_init_unicode(pylib::Module module);
 
