@@ -22,8 +22,10 @@ from vmp_json_  import Json    as Json
 from vmp_json_  import JsonObj as JsonObj
 from vmp_json_  import JData   as JData
 from vmp_json_  import JList   as JList
-from vmp_json_  import JTable   as JTable
-
-
+from vmp_json_  import JTable  as JTable
 
+from vmp_json_  import japi       as japi 
+from vmp_json_  import japi_void  as japi_void
+from vmp_json_  import japi_list  as japi_list
+from vmp_json_  import japi_table as japi_table
 
