@@ -58,7 +58,7 @@ void json_init(pylib::Module module);
 //!Python wrapper of the c++ namespace vampiria::json in vmp_json.(see c++ doc)
 /*!
     JData class in json/jdata.h:<BR>Constructor JData()<BR>
-    JData member function list:<BR>reset(),new_data(),set(),root(),jtype(),jkey(),set_text(),get_text(),set_integer(),
+    JData member function list:<BR>reset(),new_data(),set(),remove_data(),root(),jtype(),set_text(),get_text(),set_integer(),
                                   get_integer(),set_integer_range(),get_integer_range(),set_real(),get_real(),
                                   set_real_range(),get_real_range(),new_list(),set_list(),get_list(),new_table(),
                                   set_table(),get_table(),set_args(),get_args(),set_vars(),get_vars(),set_custom(),
@@ -70,16 +70,22 @@ void json_jdata(pylib::Module module);
 //!Python wrapper of the c++ namespace vampiria::json in vmp_json.(see c++ doc)
 /*!
     JList class in json/jlist.h:<BR>Constructor JList()<BR>
-    JList member function list:<BR>jdata_type(),reset(),push(),replace(),get(),size()
+    JList member function list:<BR>list(),jdata_type(),reset(),push(),replace(),get(),size()
 */
 void json_jlist(pylib::Module module);
 
 //!Python wrapper of the c++ namespace vampiria::json in vmp_json.(see c++ doc)
 /*!
     JTable class in json/jtable.h:<BR>Constructor JTable()<BR>
-    JTable member function list:<BR>jdata_type(),reset(),keys(),insert(),cancel(),search()
+    JTable member function list:<BR>table(),jdata_type(),reset(),keys(),insert(),cancel(),search()
 */
 void json_jtable(pylib::Module module);
 
+//!Python wrapper of the c++ namespace vampiria::json in vmp_json.(see c++ doc)
+/*!
+    Function c++ in json/japi.h:<BR>japi(),japi_void(),japi_list(),japi_table()
+*/
+void json_japi(pylib::Module module);
+
 #endif
 
