@@ -29,7 +29,7 @@
 
 //!Python wrapper of the c++ namespace vampiria::net in vmp_net.(see c++ doc)
 /*!
-    Function c++ in net/address.h:<BR>is_ipv4_raw(),is_ipv6_raw(),ip_to_buf(),ipv4_from_buf(),ipv6_from_buf(),
+    Function c++ in net/address.h:<BR>is_ipv4_raw(),is_ipv6_raw(),is_ip_raw(),ip_to_buf(),ipv4_from_buf(),ipv6_from_buf(),
     is_macaddress_raw(),macaddress_to_buf(),macaddress_from_buf()
 */
 /*!
