@@ -97,11 +97,16 @@ vmp_bool Manager::cell_update(event::Cell *cell)
 
 void Manager::cell_timewait(event::Cell *cell,vmp::time::Time timewait)
 {
-    cell->timewait_=timewait;
-    if(cell->timewait_ == 0.0)
-        cell->timeout_=0.0;
-    else
+    if(timewait > 0.0)
+    {
+        cell->timewait_=timewait;
         cell->timeout_=now_+cell->timewait_;
+    }
+    else
+    {
+        cell->timewait_=0.0;
+        cell->timeout_=0.0;
+    }
     breakloop();
 }
 
