@@ -69,10 +69,9 @@ class JData
         /*!
             @param root json object where the data is created
             @param jtype jdata value
-            @param jkey  jdata key value
             @return void or except in case of failure
         */
-        void new_data(json::JsonObj *root,vmp::str jtype,vmp::str jkey);
+        void new_data(json::JsonObj *root,vmp::str jtype);
 
         //! Set the structure with an existing json data object
         /*!
@@ -81,6 +80,12 @@ class JData
         */
         void set(json::JsonObj *root);
 
+        //! Remove the data of the object
+        /*!
+            @return void or except in case of failure
+        */
+        void remove_data();
+        
         //! Return the root json data object
         /*!
             @ref root_
@@ -94,13 +99,6 @@ class JData
             @return json data type or except in case of failure
         */
         vmp::str jtype();
-        
-        //! Return json data key
-        /*!
-            @ref root_
-            @return json data type or except in case of failure
-        */
-        vmp::str jkey();
 
         //! Insert a text primitive in jbody
         /*!
