@@ -186,7 +186,7 @@ vmp_bool JsonObj::replace_array(struct json_object *val,vmp_index i,vmp::str fna
     if(!isarray())
     {
         json_object_put(val);
-        vmp::except("ea::pkg::JsonObj::%s() invalid data format",fname.c_str());    
+        vmp::except("json::JsonObj::%s() invalid data format",fname.c_str());    
     }
     if(get_array_size() <= i)
     {
@@ -202,7 +202,7 @@ void JsonObj::add_object(vmp::str key,struct json_object *val,vmp::str fname)
     if(!isobject())
     {
         json_object_put(val);
-        vmp::except("ea::pkg::JsonObj::%s() this object does not object type",fname.c_str());    
+        vmp::except("json::JsonObj::%s() this object does not object type",fname.c_str());    
     }
     json_object_object_del(ref_,key.c_str());
     json_object_object_add(ref_,key.c_str(),val);
@@ -213,7 +213,7 @@ void JsonObj::push_array(struct json_object *val,vmp::str fname)
     if(!isarray())
     {
         json_object_put(val);
-        vmp::except("ea::pkg::JsonObj::%s() invalid data format",fname.c_str());    
+        vmp::except("json::JsonObj::%s() invalid data format",fname.c_str());    
     }
     json_object_array_add(ref_,val);
 }
@@ -267,7 +267,7 @@ void JsonObj::get_object(vmp::str key,JsonObj *obj)
     check_null_references("get_object");
     check_null_input_obj(obj,"get_object");
     if(!json_object_object_get_ex(ref_,key.c_str(),&value))      
-        vmp::except("ea::pkg::JsonObj::get_object('%s') json object not found",key.c_str());
+        vmp::except("json::JsonObj::get_object('%s') json object not found",key.c_str());
     obj->ref_=value;
 }
 
@@ -275,7 +275,7 @@ void JsonObj::del_object(vmp::str key)
 {
     check_null_references("del_object");
     if(!isobject())
-        vmp::except("ea::pkg::JsonObj::del_object() this object does not object type");    
+        vmp::except("json::JsonObj::del_object() this object does not object type");    
     json_object_object_del(ref_,key.c_str());
 }
 
@@ -345,28 +345,28 @@ void JsonObj::add_object_ex(vmp::str key,JsonObj *obj)
 vmp::str JsonObj::get_str()
 {
     if(!isstr())
-        vmp::except("ea::pkg::JsonObj::get_str() invalid data format");
+        vmp::except("json::JsonObj::get_str() invalid data format");
     return json_object_get_string(ref_);
 }
 
 vmp_bool JsonObj::get_bool()
 {
     if(!isbool())
-        vmp::except("ea::pkg::JsonObj::get_bool() invalid data format");
+        vmp::except("json::JsonObj::get_bool() invalid data format");
     return json_object_get_boolean(ref_);
 }
 
 vmp_real JsonObj::get_number()
 {
     if(!isnumber())
-        vmp::except("ea::pkg::JsonObj::get_number() invalid data format");
+        vmp::except("json::JsonObj::get_number() invalid data format");
     return json_object_get_double(ref_);   
 }
 
 vmp_size JsonObj::get_array_size()
 {
     if(!isarray())
-        vmp::except("ea::pkg::JsonObj::get_array_size() invalid data format");
+        vmp::except("json::JsonObj::get_array_size() invalid data format");
     return (vmp_size)json_object_array_length(ref_);
 }
 
@@ -375,7 +375,7 @@ vmp_bool JsonObj::get_array_idx(vmp_index i,JsonObj *obj)
     struct json_object *value;
     check_null_input_obj(obj,"get_array_idx");
     if(!isarray())
-        vmp::except("ea::pkg::JsonObj::get_array_idx() invalid data format");
+        vmp::except("json::JsonObj::get_array_idx() invalid data format");
     if(i < get_array_size())
     {
         value=json_object_array_get_idx(ref_,i);
@@ -552,7 +552,7 @@ vmp::vector<vmp::str> JsonObj::get_object_array_strings(vmp::str key)
     }
     catch(vmp::exception &x)
     {
-        vmp::except("ea::pkg::JsonObj::get_array_strings() invalid data format");
+        vmp::except("json::JsonObj::get_array_strings() invalid data format");
         return ret;
     }
     for(vmp_index i=0;i<size;i++)
@@ -565,7 +565,7 @@ vmp::vector<vmp::str> JsonObj::get_object_array_strings(vmp::str key)
         catch(vmp::exception &x)
         {
             ret.clear();
-            vmp::except("ea::pkg::JsonObj::get_array_strings() invalid data format index '%d'",i);
+            vmp::except("json::JsonObj::get_array_strings() invalid data format index '%d'",i);
             return ret;
         }
     }
@@ -584,7 +584,7 @@ vmp::vector<vmp_real> JsonObj::get_object_array_numbers(vmp::str key)
     }
     catch(vmp::exception &x)
     {
-        vmp::except("ea::pkg::JsonObj::get_array_numbers() invalid data format");
+        vmp::except("json::JsonObj::get_array_numbers() invalid data format");
         return ret;
     }
     for(vmp_index i=0;i<size;i++)
@@ -597,7 +597,7 @@ vmp::vector<vmp_real> JsonObj::get_object_array_numbers(vmp::str key)
         catch(vmp::exception &x)
         {
             ret.clear();
-            vmp::except("ea::pkg::JsonObj::get_array_numbers() invalid data format index '%d'",i);
+            vmp::except("json::JsonObj::get_array_numbers() invalid data format index '%d'",i);
             return ret;
         }
     }
@@ -616,7 +616,7 @@ vmp::vector<vmp_bool> JsonObj::get_object_array_bools(vmp::str key)
     }
     catch(vmp::exception &x)
     {
-        vmp::except("ea::pkg::JsonObj::get_array_bools() invalid data format");
+        vmp::except("json::JsonObj::get_array_bools() invalid data format");
         return ret;
     }
     for(vmp_index i=0;i<size;i++)
@@ -629,7 +629,7 @@ vmp::vector<vmp_bool> JsonObj::get_object_array_bools(vmp::str key)
         catch(vmp::exception &x)
         {
             ret.clear();
-            vmp::except("ea::pkg::JsonObj::get_array_bools() invalid data format index '%d'",i);
+            vmp::except("json::JsonObj::get_array_bools() invalid data format index '%d'",i);
             return ret;
         }
     }
