@@ -212,7 +212,7 @@ void Address::set(vmp::str host,vmp::str service)
         vmp::except("net::Address::set(service='%s') invalid service input",service.c_str());
     }
     service_=service;
-    if(dnstype_ == "system")
+    if(net::is_ip_raw(host) || (dnstype_ == "system"))
     {
         host_=host;
         init();
