@@ -286,7 +286,7 @@ class Args
 		{
 		     tmp.set(pylib::pytuple_getitem(tuple_,init_+i));  
 		     tmp.set(tmp.get_attr(name).ref());
-                     return tmp.get<T>(name);
+                     return tmp.get<T>();
 		}
 		catch(vmp::exception &e)
 		{
@@ -295,7 +295,7 @@ class Args
 	   if(argerr_ < (vmp_int) i) 
                  argerr_=(vmp_int) i;
 	   arg_error();
-	   return tmp.get<T>(name);
+	   return tmp.get<T>();
        }
 	
       //!Get index generic python object
