@@ -460,13 +460,40 @@ vmp_bool pydict_check(pylib::Objref *dict)
     return true;
 }
 
-void pydict_clear(pylib::Objref *dict)
+vmp_bool pydict_next(pylib::Objref *dict,Py_ssize_t *ppos,pylib::Objref **pkey,pylib::Objref **pvalue)
 {
     if(!pydict_check(dict))
-       vmp::except_s("pydict_clear error input objref not dict type");
-    PyObject *key, *value;
-    Py_ssize_t pos = 0;
-    while (PyDict_Next(dict, &pos, &key, &value)) 
+       vmp::except_s("pydict_next error input objref not dict type");
+    if(PyDict_Next(dict,ppos,pkey,pvalue))
+    {
+        pylib::pyerr_clear();
+        return true;
+    }
+    pylib::pyerr_clear();
+    return false;    
+}
+
+void pydict_setitem(pylib::Objref *dict,pylib::Objref *key,pylib::Objref *val)
+{
+    if(!pydict_check(dict))
+       vmp::except_s("pydict_setitem error input objref not dict type");
+    try
+    {
+        if(PyDict_SetItem(dict,key,val) != 0)
+            vmp::except_s();
+    }
+    catch(vmp::exception &x)
+    {
+        pylib::pyerr_clear();
+        vmp::except_s("pydict_setitem insert error");
+    }
+}
+
+void pydict_clear(pylib::Objref *dict)
+{
+    pylib::Objref *key,*value;
+    Py_ssize_t pos=0;
+    while(pylib::pydict_next(dict,&pos,&key,&value)) 
     {
         pylib::decref(key);
         pylib::decref(value);
