@@ -52,6 +52,16 @@ openssl0.libs=[('openssl','1.1.1k')]
 openssl0.loptions=['`pkg-config --libs  openssl`']
 lib.clibs_[openssl0.name]=openssl0
 
+openssl1=lib.clib()
+openssl1.name='openssl1'
+openssl1.dependencies=['vmp','net']
+openssl1.pkg=True
+openssl1.cmd=['openssl version','chmod --version','cp --version']
+openssl1.files=[('openssl/',['lib','hash','openssl','x509','pkey','sslevent','sslui']),('openssl/ctx/',['ctx','base','peer'])]
+openssl1.libs=[('openssl','1.1.1k')]
+openssl1.loptions=['`pkg-config --libs  openssl`']
+lib.clibs_[openssl1.name]=openssl1
+
 vmp_xterm0=pylib.pylib()
 vmp_xterm0.name='vmp_xterm0'
 vmp_xterm0.dependencies=[]
@@ -76,6 +86,15 @@ vmp_openssl0.setup.files=[('./',['openssl_','pkey_','x509_','sslui_'])]
 vmp_openssl0.setup.dependencies=['pylib','openssl0']
 pylib.pylibs_[vmp_openssl0.name]=vmp_openssl0
 
+vmp_openssl1=pylib.pylib()
+vmp_openssl1.name='vmp_openssl1'
+vmp_openssl1.dependencies=['vmp','vmp_net']
+vmp_openssl1.pkg=True
+vmp_openssl1.cbuild()
+vmp_openssl1.setup.files=[('./',['openssl_','hash_','pkey_','x509_','sslui_','ctx_'])]
+vmp_openssl1.setup.dependencies=['pylib','openssl1']
+pylib.pylibs_[vmp_openssl1.name]=vmp_openssl1
+
 vmp_rawnet1=pylib.pylib()
 vmp_rawnet1.name='vmp_rawnet1'
 vmp_rawnet1.dependencies=['vmp','vmp_event']
